WindowsPlatformWebViewCookieManager class
- Inheritance
-
- Object
- PlatformInterface
- WindowsPlatformWebViewCookieManager
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
params
→ PlatformWebViewCookieManagerCreationParams
-
The parameters used to initialize the
PlatformWebViewCookieManager.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCookies()
→ Future<bool>
-
Clears all cookies for all
WebView instances.
-
getCookies(Uri url)
→ Future<List<WebViewCookie>>
-
Returns a list of existing cookies for the specified domain from all
WebView instances of the application.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setCookie(WebViewCookie cookie)
→ Future<void>
-
Sets a cookie for all
WebView instances.
-
toString()
→ String
-
A string representation of this object.
inherited