profileName property

String? profileName
final

Optional profile name for session isolation.

When specified, WebView2 will use a named profile to isolate cookies, cache, and storage from other WebView instances, while sharing the same underlying browser process (more memory-efficient than separate environments). This works like Chrome's user profiles.

See: https://learn.microsoft.com/en-us/microsoft-edge/webview2/concepts/multi-profile-support

Implementation

final String? profileName;