WinWebViewPermissionRequest class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WinWebViewPermissionResourceType
-
final
- platform → PlatformWebViewPermissionRequest
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ Set<
WebViewPermissionResourceType> -
All resources access has been requested for.
finalinherited
- url → String
-
final
Methods
-
deny(
) → Future< void> - Deny permission for the requested resource(s).
-
denyIfNoAction(
) → Future< void> -
grant(
) → Future< void> - Grant permission for the requested resource(s).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited